@@ -1,13 +1,11 @@
-context("as.location")
-
 test_that("as.location returns correct class", {
   skip_on_cran()
 
   url <- "https://raw.githubusercontent.com/glynnbird/usstatesgeojson/master/california.geojson"
   b <- as.location(url)
 
-  expect_is(b, "location_")
-  expect_is(b[[1]], "character")
+  expect_s3_class(b, "location_")
+  expect_type(b[[1]], "character")
   expect_null(names(b))
 })
 
@@ -18,7 +16,7 @@ test_that("as.location print method works as expected", {
   b <- as.location(url)
   txt <- capture.output(print.location_(b))
 
-  expect_is(txt, "character")
+  expect_type(txt, "character")
   expect_equal(length(txt), 3)
   expect_true(grepl("location", txt[1]))
   expect_true(grepl("geojson", txt[3]))
