@@ -1,11 +1,9 @@
-context("geojson_json")
-
 test_that("geojson_json works with numeric inputs", {
   skip_on_cran()
 
   # From a numeric vector of length 2, making a point type
   a <- geojson_json(c(-99.74, 32.45))
-  expect_is(a, "json")
+  expect_s3_class(a, "json")
   expect_equal(attr(a, "type"), "FeatureCollection")
   expect_equal(attr(a, "no_features"), "1")
   expect_equal(attr(a, "five_feats"), "Point")
@@ -15,7 +13,7 @@ test_that("geojson_json works with numeric inputs", {
     a,
     "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"geometry\":{\"type\":\"Point\",\"coordinates\":[-99.74,32.45]},\"properties\":{}}]}"
   )
-  expect_is(unclass(a), "character")
+  expect_type(unclass(a), "character")
   expect_equal(jsonlite::fromJSON(a)$type, "FeatureCollection")
 
   aa <- unclass(geojson_json(c(-99.74, 32.45), type = "GeometryCollection"))
@@ -58,7 +56,7 @@ test_that("geojson_json works with data.frame inputs", {
   # from data.frame to polygons
   aa <- unclass(geojson_json(states[1:351, ], lat = "lat", lon = "long", geometry = "polygon", group = "group"))
   attributes(aa) <- NULL
-  expect_equal_to_reference(object = aa, file = "numericstates.rds")
+  expect_snapshot_value(aa, style = "json2")
 })
 
 test_that("geojson_json works with data.frame inputs", {
@@ -95,7 +93,7 @@ test_that("geojson_json detects inproper polygons passed as lists inputs", {
 
   # fine
   fine <- geojson_json(good, geometry = "polygon")
-  expect_is(fine, "json")
+  expect_s3_class(fine, "json")
 
   # bad
   expect_error(
@@ -104,7 +102,7 @@ test_that("geojson_json detects inproper polygons passed as lists inputs", {
   )
 
   # doesn't matter if geometry != polygon
-  expect_is(geojson_json(bad), "json")
+  expect_s3_class(geojson_json(bad), "json")
 })
 
 test_that("geojson_json - acceptable type values for numeric/data.frame/list", {
@@ -127,7 +125,7 @@ test_that("geojson_json - acceptable type values for numeric/data.frame/list", {
   )
 })
 
-test_that("skipping geoclass works with type = skip", {
+test_that("skipping geoclass in geojson_json works with type = skip", {
   skip_on_cran()
 
   x <- geojson_sp(geojson_json(c(-99.74, 32.45)))
@@ -135,12 +133,11 @@ test_that("skipping geoclass works with type = skip", {
   expect_null(attr(geojson_json(x, type = "skip"), "type"))
 })
 
-context("geojson_json precision")
-def_digits <- getOption("digits")
-options(digits = 15)
-test_that("precision", {
+test_that("geojson_json precision", {
   skip_on_cran()
 
+  withr::local_options(digits = 15)
+
   # numeric
   x <- geojson_json(c(-99.123456789, 32.12345678), precision = 10)
   expect_equal(num_digits(x), c(9, 8))
@@ -161,12 +158,15 @@ test_that("precision", {
   expect_equal(num_digits(x), c(0, 3, 7, 2))
 
   # from geojson_list output
-  a <- geojson_list(df, precision = 5)
+  a <- geojson_list(df, precision = 5, lat = "lat", lon = "lon")
   x <- geojson_json(a, precision = 5)
   expect_equal(num_digits(x), c(0, 3, 5, 2))
+})
 
-  # sp classes: SpatialPolygons
-  library("sp")
+test_that("geojson_json precision for sp classes", {
+  skip_on_cran()
+  withr::local_options(digits = 15)
+  
   poly1 <- Polygons(list(Polygon(cbind(
     c(-100.1, -90.12, -85.123, -100.1234),
     c(40, 50, 45, 40)
@@ -184,22 +184,23 @@ test_that("precision", {
     num_digits(geojson_json(sp_poly, precision = 2)),
     c(1, 2, 2, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
   )
+})
+
+test_that("geojson_json precision for sf classes", {
+  skip_on_cran()
+  skip_if_not_installed("sf")
+
+  withr::local_options(digits = 15)
 
-  # sf classes
-  library("sf")
   p1 <- rbind(c(0, 0), c(1, 0), c(3, 2), c(2, 4), c(1, 4.1234567), c(0, 0))
   p2 <- rbind(c(5.123, 5.1), c(5, 6), c(4, 5), c(5.123, 5.1))
-  poly_sfc <- st_sfc(st_polygon(list(p1)), st_polygon(list(p2)))
+  poly_sfc <- sf::st_sfc(sf::st_polygon(list(p1)), sf::st_polygon(list(p2)))
   expect_equal(
     num_digits(geojson_json(poly_sfc)),
     c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 3, 0, 0, 3, 1, 0, 0, 1)
   )
-  # FIXME: not working yet
   expect_equal(
     num_digits(geojson_json(poly_sfc, precision = 2)),
     c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 3, 0, 0, 3, 1, 0, 0, 1)
   )
 })
-
-# reset digits to default value
-options(digits = def_digits)
