@@ -1,5 +1,3 @@
-context("rbind_fill")
-
 test_that("rbind_fill works with built in datasets", {
   skip_on_cran()
 
@@ -8,9 +6,9 @@ test_that("rbind_fill works with built in datasets", {
   aa <- geojsonio:::rbind_fill(df1, df2)
 
   # classes
-  expect_is(df1, "data.frame")
-  expect_is(df2, "data.frame")
-  expect_is(aa, "data.frame")
+  expect_s3_class(df1, "data.frame")
+  expect_s3_class(df2, "data.frame")
+  expect_s3_class(aa, "data.frame")
 
   # values
   expect_named(df1, c("a", "b"))
