@@ -1,10 +1,8 @@
-context("topojson_list")
-
 test_that("topojson_list works with numeric inputs", {
   skip_on_cran()
 
   aa <- topojson_list(c(-99.74, 32.45), quiet = TRUE)
-  expect_is(aa, "list")
+  expect_type(aa, "list")
 })
 
 test_that("topojson_list works with numeric inputs for polygons", {
@@ -18,7 +16,7 @@ test_that("topojson_list works with numeric inputs for polygons", {
     c(-114.345703125, 39.436192999314095)
   )
   aa <- topojson_list(poly, type = "GeometryCollection", quiet = TRUE)
-  expect_is(aa, "list")
+  expect_type(aa, "list")
 })
 
 test_that("topojson_list works with list inputs", {
@@ -29,23 +27,29 @@ test_that("topojson_list works with list inputs", {
     c(100.0, 0.0)
   )
   aa <- topojson_list(vecs, geometry = "polygon")
-  expect_is(aa, "list")
+  expect_type(aa, "list")
 })
 
 test_that("topojson_list works with data.frame inputs", {
   skip_on_cran()
 
   aa <- topojson_list(us_cities[1:2, ], lat = "lat", lon = "long")
-  expect_is(aa, "list")
+  expect_type(aa, "list")
 })
 
 test_that("topojson_list object_name param works", {
   skip_on_cran()
 
   # default
-  aa <- topojson_list(us_cities[1:2, ], quiet = TRUE)
+  aa <- topojson_list(us_cities[1:2, ], quiet = TRUE, lat = "lat", lon = "long")
   expect_named(aa$objects, "foo")
   # custom object name
-  bb <- topojson_list(us_cities[1:2, ], object_name = "stuff", quiet = TRUE)
+  bb <- topojson_list(
+    us_cities[1:2, ],
+    object_name = "stuff",
+    quiet = TRUE,
+    lat = "lat",
+    lon = "long"
+  )
   expect_named(bb$objects, "stuff")
 })
